==> agrosyst-web-1.4.1-sources.jar: fr/inra/agrosyst/web/actions/auth/ForgottenPassword.java <==
package fr.inra.agrosyst.web.actions.auth;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: ForgottenPassword.java 3696 2014-03-10 17:50:15Z echatellier $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.4.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/auth/ForgottenPassword.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;

import fr.inra.agrosyst.api.services.users.UserService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * @author Arnaud Thimel : thimel@codelutin.com
 */
public class ForgottenPassword extends AbstractAgrosystAction {

    private static final long serialVersionUID = 2328784341047848966L;

    protected transient UserService userService;

    protected String email;
    protected boolean reminderSent;

    public void setUserService(UserService userService) {
        this.userService = userService;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    @Action("forgotten-password-input")
    public String input() throws Exception {
        return super.input();
    }

    @Override
    public String execute() throws Exception {

        reminderSent = userService.askForPasswordReminder(email);
        if (reminderSent) {
            addActionMessage("Email de récupération du mot de passe envoyé, consultez votre boîte mail");
        } else {
            addFieldError("email", "L'email indiqué n'est pas connu par le système");
        }
        return INPUT;
    }

    public String getEmail() {
        return email;
    }

    public boolean isReminderSent() {
        return reminderSent;
    }

}

==> agrosyst-web-1.5-sources.jar: fr/inra/agrosyst/web/actions/auth/ForgottenPassword.java <==
package fr.inra.agrosyst.web.actions.auth;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: ForgottenPassword.java 3696 2014-03-10 17:50:15Z echatellier $
 * $HeadURL: https://svn.codelutin.com/agrosyst/tags/agrosyst-1.5/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/auth/ForgottenPassword.java $
 * %%
 * Copyright (C) 2013 - 2014 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import org.apache.struts2.convention.annotation.Action;

import fr.inra.agrosyst.api.services.users.UserService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * @author Arnaud Thimel : thimel@codelutin.com
 */
public class ForgottenPassword extends AbstractAgrosystAction {

    private static final long serialVersionUID = 2328784341047848966L;

    protected transient UserService userService;

    protected String email;
    protected boolean reminderSent;

    public void setUserService(UserService userService) {
        this.userService = userService;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    @Override
    @Action("forgotten-password-input")
    public String input() throws Exception {
        return super.input();
    }

    @Override
    public String execute() throws Exception {

        reminderSent = userService.askForPasswordReminder(email);
        if (reminderSent) {
            addActionMessage("Email de récupération du mot de passe envoyé, consultez votre boîte mail");
        } else {
            addFieldError("email", "L'email indiqué n'est pas connu par le système");
        }
        return INPUT;
    }

    public String getEmail() {
        return email;
    }

    public boolean isReminderSent() {
        return reminderSent;
    }

}
